@@ -1,6 +1,6 @@
 #' Plot results of an SSVS model
 #'
-#' @param x An SSVS result object obtained from [`ssvs()`]
+#' @param x An ssvs result object obtained from [`ssvs()`]
 #' @param threshold An MIP threshold to show on the plot, must be between 0-1.
 #' If `NULL`, no threshold is used.
 #' @param legend If `TRUE`, show a legend for the shapes based on the threshold.
@@ -20,15 +20,16 @@
 #' @importFrom rlang .data
 plot.ssvs <- function(x, threshold = 0.5, legend = TRUE, title = NULL, color = TRUE,
                       ...) {
+  # Basic checks and setup
   assert_ssvs(x)
   checkmate::assert_number(threshold, lower = 0, upper = 1, null.ok = TRUE)
   checkmate::assert_logical(legend, len = 1, any.missing = FALSE)
   checkmate::assert_string(title, null.ok = TRUE)
 
-  # Recreate a dataframe of the results
-  plotDF <- as.data.frame(apply(x$beta!=0,2,mean))
+  # Data preparation
+  plotDF <- as.data.frame(apply(x$beta != 0, 2, mean))
   plotDF$var <- rownames(plotDF)
-  names(plotDF) <- c("Inclusion_probability","Variable_name")
+  names(plotDF) <- c("Inclusion_probability", "Variable_name")
   plotDF <- plotDF[order(-plotDF$Inclusion_probability),]
 
   if (is.null(threshold)) {
@@ -65,18 +66,18 @@ plot.ssvs <- function(x, threshold = 0.5, legend = TRUE, title = NULL, color = T
     ggplot2::theme(axis.text.x = ggplot2::element_text(angle = 90, hjust = 1),
                    panel.spacing = ggplot2::unit(0, "lines"),
                    strip.background = ggplot2::element_blank(),
-                   strip.placement = "outside") +
-    ggplot2::guides(shape = FALSE, color = FALSE)
+                   strip.placement = "outside")
 
   if (!is.null(threshold)) {
     plt <- plt +
-      ggplot2::labs(shape = "MIP threshold") +
+      ggplot2::labs(shape = "MIP threshold", color = "MIP threshold") +
       ggplot2::geom_hline(yintercept = threshold, linetype = 2)
     if (legend) {
-      plt <- plt + ggplot2::guides(shape = ggplot2::guide_legend())
+      plt <- plt + ggplot2::guides(shape = "legend", color = "legend")
+    } else {
+      plt <- plt + ggplot2::guides(shape = "none", color = "none")  # Correctly disable the legends using "none"
     }
   }
 
   plt
 }
-
